//Importing necessary modules
import { getData } from './getData';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
//Define constant function to format Tick values 
const xAxisTickFormat = number =>
  	format('.4~g')(number);
const render = (data, total) => {
  // Slice the data to only show 10 items
  const slicedData = data.slice(9320, 9330);

  const pieData = pie().value(d => d.Score)(slicedData);
//Assign colors scale to the pie - colors are mentioned in the range
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
  "#004c6d",
  "#346888",
  "#588bae",
  "#7fb3d5",
  "#add8ea",
  "#cfe0d4",
  "#e1ddc0",
  "#f2cfa7",
  "#ffa588",
  "#ee6c4d",
  "#b5312c",
  "#8c0d0d",
  "#5a0000",
  "#8f75be",
  "#b89dda",
  "#dbb7e8",
  "#f9c6e7",
  "#ff99cc",
  "#d63230",
  "#e45f56"
    ]);
// Define the arc for the segments of the pie chart
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
// Select the SVG element and append a group element for the sections of the pie chart
  const sections = svg.append("g")
  	.attr("transform", `translate(215,200)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.GameName));
// Add new path elements for the data items that don't have a corresponding path element
  const legends = svg.append("g")
  	.attr("transform", "translate(430,20)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });

  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.GameName));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 20)
  	.attr("class","legend_text")
  	.text(d => d.data.GameName)
  	.style("fill", "white");

  legend.append("text")
  	.attr("x", 430)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Score)))
  	.style("fill", "white");
}
// Define a function that fetches data and renders the pie chart
const run = async () => {
  let data = await getData()
  let total = 0
  data.forEach(d=>{
    d.Score = +d.Score;
    total += d.Score
  });

  console.log(data)
	render(data,total);
};
run();